Range-v3: ranges::v3::concepts::BoundedIterable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::BoundedIterable Struct Reference
Concepts
Inheritance diagram for ranges::v3::concepts::BoundedIterable:

## Public Member Functions
template<typename T >
auto | requires_ (T &&t) -> decltype(concepts::valid_expr(concepts::same_type(begin(t), end(t))))
Public Member Functions inherited from ranges::v3::concepts::refines< Iterable >
void | requires_ (Ts &&...)

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< Iterable >
using | base_concepts_t = meta::list< Concepts...>